@@ -13,12 +13,13 @@
     EHm => "E HH.mm",
     EHms => "E HH.mm.ss",
     Ed => "E, d",
-    Ehm => "E h.mm a",
-    Ehms => "E h.mm.ss a",
+    Ehm => "E h.mm\N{U+202f}a",
+    Ehms => "E h.mm.ss\N{U+202f}a",
     Gy => "y G",
     GyMMM => "MMM y G",
     GyMMMEd => "E, d MMM y G",
     GyMMMd => "d MMM y G",
+    GyMd => "d/M/y GGGGG",
     H => "HH",
     Hm => "HH.mm",
     Hms => "HH.mm.ss",
@@ -29,16 +30,16 @@
     MMM => "LLL",
     MMMEd => "E, d MMM",
     MMMMEd => "E, d MMMM",
-    "MMMMW-count-other" => "'minggu' 'ke'-W MMM",
+    "MMMMW-count-other" => "'minggu' 'ke'-W MMMM",
     MMMMd => "d MMMM",
     MMMd => "d MMM",
     Md => "d/M",
     d => "d",
-    h => "h a",
-    hm => "h.mm a",
-    hms => "h.mm.ss a",
+    h => "h\N{U+202f}a",
+    hm => "h.mm\N{U+202f}a",
+    hms => "h.mm.ss\N{U+202f}a",
     hmsv => "h.mm.ss. a v",
-    hmv => "h.mm a v",
+    hmv => "h.mm\N{U+202f}a v",
     ms => "mm.ss",
     y => "y",
     yM => "M/y",
@@ -142,7 +143,7 @@
     "Mei",
     "Jun",
     "Jul",
-    "Agt",
+    "Agu",
     "Sep",
     "Okt",
     "Nov",
@@ -184,7 +185,7 @@
     "Mei",
     "Jun",
     "Jul",
-    "Agt",
+    "Agu",
     "Sep",
     "Okt",
     "Nov",
@@ -267,5 +268,5 @@
   time_format_medium => "HH.mm.ss",
   time_format_short => "HH.mm",
   variant => undef,
-  version => 33,
+  version => "44.1",
 }
