@@ -10,15 +10,16 @@
     E => "ccc",
     EBhm => "E h:mm B",
     EBhms => "E h:mm:ss B",
-    EHm => "E HH:mm",
-    EHms => "E HH:mm:ss",
+    EHm => "E 'kl'. HH:mm",
+    EHms => "E 'kl'. HH:mm:ss",
     Ed => "E d.",
-    Ehm => "E h:mm a",
-    Ehms => "E h:mm:ss a",
+    Ehm => "E h:mm\N{U+202f}a",
+    Ehms => "E h:mm:ss\N{U+202f}a",
     Gy => "y G",
     GyMMM => "MMM y G",
     GyMMMEd => "E d. MMM y G",
     GyMMMd => "d. MMM y G",
+    GyMd => "dd.MM.y GGGGG",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -28,22 +29,22 @@
     MEd => "E d.M.",
     MMM => "LLL",
     MMMEd => "E d. MMM",
-    "MMMMW-count-one" => "W. 'uke' 'i' MMMM",
-    "MMMMW-count-other" => "W. 'uke' 'i' MMMM",
+    "MMMMW-count-one" => "'den' W. 'uken' 'i' MMMM",
+    "MMMMW-count-other" => "'den' W. 'uken' 'i' MMMM",
     MMMMd => "d. MMMM",
     MMMd => "d. MMM",
     MMdd => "d.M.",
     Md => "d.M.",
     d => "d.",
-    h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a v",
-    hmv => "h:mm a v",
+    h => "h\N{U+202f}a",
+    hm => "h:mm\N{U+202f}a",
+    hms => "h:mm:ss\N{U+202f}a",
+    hmsv => "h:mm:ss\N{U+202f}a v",
+    hmv => "h:mm\N{U+202f}a v",
     ms => "mm:ss",
     y => "y",
     yM => "M.y",
-    yMEd => "E d.MM.y",
+    yMEd => "E d.M.y",
     yMM => "MM.y",
     yMMM => "MMM y",
     yMMMEd => "E d. MMM y",
@@ -60,8 +61,8 @@
   date_format_long => "d. MMMM y",
   date_format_medium => "d. MMM y",
   date_format_short => "dd.MM.y",
-  datetime_format_full => "{1} {0}",
-  datetime_format_long => "{1} 'kl'. {0}",
+  datetime_format_full => "{1}, {0}",
+  datetime_format_long => "{1}, {0}",
   datetime_format_medium => "{1}, {0}",
   datetime_format_short => "{1}, {0}",
   day_format_abbreviated => [
@@ -140,11 +141,11 @@
   month_format_abbreviated => [
     "jan.",
     "feb.",
-    "mar.",
+    "mars",
     "apr.",
     "mai",
-    "jun.",
-    "jul.",
+    "juni",
+    "juli",
     "aug.",
     "sep.",
     "okt.",
@@ -270,5 +271,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 35,
+  version => "44.1",
 }
