@@ -13,12 +13,13 @@
     EHm => "E, HH:mm",
     EHms => "E, HH:mm:ss",
     Ed => "E, d",
-    Ehm => "E, h:mm a",
-    Ehms => "E, h:mm:ss a",
+    Ehm => "E, h:mm\N{U+202f}a",
+    Ehms => "E, h:mm:ss\N{U+202f}a",
     Gy => "y G",
     GyMMM => "MMM y G",
     GyMMMEd => "E, d MMM y G",
     GyMMMd => "d MMM y G",
+    GyMd => "d.M.y GGGG",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -36,11 +37,11 @@
     MMdd => "d.M",
     Md => "d.M",
     d => "d",
-    h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a, v",
-    hmv => "h:mm a, v",
+    h => "h\N{U+202f}a",
+    hm => "h:mm\N{U+202f}a",
+    hms => "h:mm:ss\N{U+202f}a",
+    hmsv => "h:mm:ss\N{U+202f}a, v",
+    hmv => "h:mm\N{U+202f}a, v",
     ms => "mm:ss",
     y => "y",
     yM => "M.y",
@@ -60,18 +61,18 @@
   date_format_long => "d MMMM y",
   date_format_medium => "d MMM y",
   date_format_short => "d.M.yy",
-  datetime_format_full => "{1} 'n\N{U+00eb}' {0}",
-  datetime_format_long => "{1} 'n\N{U+00eb}' {0}",
+  datetime_format_full => "{1}, {0}",
+  datetime_format_long => "{1}, {0}",
   datetime_format_medium => "{1}, {0}",
   datetime_format_short => "{1}, {0}",
   day_format_abbreviated => [
-    "H\N{U+00eb}n",
-    "Mar",
-    "M\N{U+00eb}r",
-    "Enj",
-    "Pre",
-    "Sht",
-    "Die",
+    "h\N{U+00eb}n",
+    "mar",
+    "m\N{U+00eb}r",
+    "enj",
+    "pre",
+    "sht",
+    "die",
   ],
   day_format_narrow => [
     "h",
@@ -265,10 +266,10 @@
   ],
   script => undef,
   territory => undef,
-  time_format_full => "h:mm:ss a, zzzz",
-  time_format_long => "h:mm:ss a, z",
-  time_format_medium => "h:mm:ss a",
-  time_format_short => "h:mm a",
+  time_format_full => "h:mm:ss\N{U+202f}a, zzzz",
+  time_format_long => "h:mm:ss\N{U+202f}a, z",
+  time_format_medium => "h:mm:ss\N{U+202f}a",
+  time_format_short => "h:mm\N{U+202f}a",
   variant => undef,
-  version => 38,
+  version => "44.1",
 }
